@@ -23,15 +23,14 @@ build_time_vars = {'ABIFLAGS': '',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'm68k--netbsdelf',
+ 'BUILD_GNU_TYPE': 'armv6--netbsdelf-eabihf',
  'BUILD_SCRIPTS_DIR': 'build/scripts-3.12',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-           '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-           '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-           '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include',
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
+           '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+           '-I/usr/include -I/usr/pkg/include',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -40,8 +39,7 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2 -fno-reorder-blocks -I/usr/include '
-                     '-I/usr/pkg/include',
+ 'CONFIGURE_CFLAGS': '-O2 -I/usr/include -I/usr/pkg/include',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -56,23 +54,24 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--without-ensurepip' '--without-pymalloc' "
                 "'--with-readline=readline' '--prefix=/usr/pkg' "
-                "'--build=m68k--netbsdelf' '--host=m68k--netbsdelf' "
-                "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=m68k--netbsdelf' 'host_alias=m68k--netbsdelf' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python312/work.m68k/.tools/bin/pkg-config' "
+                "'--build=armv6--netbsdelf-eabihf' "
+                "'--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
+                "'--enable-option-checking=yes' "
+                "'build_alias=armv6--netbsdelf-eabihf' "
+                "'host_alias=armv6--netbsdelf-eabihf' "
+                "'PKG_CONFIG=/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python312/work.m68k/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python312/work.m68k/.buildlink/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-O2 -fno-reorder-blocks -I/usr/include "
-                "-I/usr/pkg/include' 'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib "
-                '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
-                "-Wl,-R/usr/X11R7/lib' 'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include "
-                "-I/usr/pkg/include'",
+                "'PKG_CONFIG_LIBDIR=/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/.buildlink/lib/pkgconfig:/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/.buildlink/share/pkgconfig' "
+                "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
+                "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
+                "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
+                "'LIBS=-lcrypt' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.8/coverage.info',
+ 'COVERAGE_INFO': '/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/Python-3.12.10/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.8/lcov-report',
+ 'COVERAGE_REPORT': '/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/Python-3.12.10/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -99,7 +98,7 @@ build_time_vars = {'ABIFLAGS': '',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DSYMUTIL': '',
  'DSYMUTIL_PATH': '',
  'DTRACE': '',
@@ -253,7 +252,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_FUTIMES': 1,
  'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
- 'HAVE_GCC_ASM_FOR_MC68881': 1,
+ 'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
  'HAVE_GCC_UINT128_T': 0,
@@ -369,7 +368,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MADVISE': 1,
  'HAVE_MAKEDEV': 1,
  'HAVE_MBRTOWC': 1,
- 'HAVE_MEMFD_CREATE': 0,
+ 'HAVE_MEMFD_CREATE': 1,
  'HAVE_MEMRCHR': 1,
  'HAVE_MINIX_CONFIG_H': 0,
  'HAVE_MKDIRAT': 1,
@@ -550,6 +549,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
+ 'HAVE_SYS_PIDFD_H': 0,
  'HAVE_SYS_POLL_H': 1,
  'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
@@ -583,7 +583,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
- 'HAVE_TTYNAME': 1,
+ 'HAVE_TTYNAME_R': 1,
  'HAVE_TZNAME': 0,
  'HAVE_UMASK': 1,
  'HAVE_UNAME': 1,
@@ -618,7 +618,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'm68k--netbsdelf',
+ 'HOST_GNU_TYPE': 'armv6--netbsdelf-eabihf',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
                    '/usr/pkg/include/python3.12 /usr/pkg/include/python3.12',
  'INCLUDEDIR': '/usr/pkg/include',
@@ -652,9 +652,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/pkg/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
@@ -665,9 +664,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBEXPAT_OBJS': '\\',
  'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
                    '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -682,9 +680,8 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
                     '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                    '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
                     '-std=gnu11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
@@ -1015,7 +1012,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DNDEBUG -O2 -fno-reorder-blocks -I/usr/include -I/usr/pkg/include',
+ 'OPT': '-DNDEBUG -O2 -I/usr/include -I/usr/pkg/include',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1051,12 +1048,10 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                             '-fno-reorder-blocks -I/usr/include '
-                             '-I/usr/pkg/include -O2 -fno-reorder-blocks '
                              '-I/usr/include -I/usr/pkg/include -O2 '
-                             '-fno-reorder-blocks -I/usr/include '
-                             '-I/usr/pkg/include -std=gnu11 -Wextra '
-                             '-Wno-unused-parameter '
+                             '-I/usr/include -I/usr/pkg/include -O2 '
+                             '-I/usr/include -I/usr/pkg/include -std=gnu11 '
+                             '-Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
@@ -1064,19 +1059,17 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include -I/usr/pkg/include '
                              '-I/usr/include -I/usr/pkg/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-              '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-              '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-              '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include',
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 -I/usr/include '
+              '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
+              '-I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu11 -Wextra -Wno-unused-parameter '
                      '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include -O2 '
-                   '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
+                   '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                   '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
                    '-std=gnu11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -1105,10 +1098,9 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -O2 '
-                        '-fno-reorder-blocks -I/usr/include -I/usr/pkg/include '
-                        '-O2 -fno-reorder-blocks -I/usr/include '
-                        '-I/usr/pkg/include -O2 -fno-reorder-blocks '
-                        '-I/usr/include -I/usr/pkg/include -std=gnu11 -Wextra '
+                        '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -O2 -I/usr/include '
+                        '-I/usr/pkg/include -std=gnu11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -1126,7 +1118,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.8',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/Python-3.12.10',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1173,7 +1165,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 12,
+ 'SIZEOF_LONG_DOUBLE': 8,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -1204,10 +1196,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.8 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/Python-3.12.10 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.8 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/Python-3.12.10 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1235,10 +1227,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 0,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 1,
+ 'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.8',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python312/work.m68k/Python-3.12.8',
+ 'abs_builddir': '/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/Python-3.12.10',
+ 'abs_srcdir': '/mnt/earmv6hf/pkgsrc/lang/python312/work.earmv6hf/Python-3.12.10',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
